@@ -568,6 +568,9 @@ class Artifact(object):
         """
         return os.path.join(self.artifacts_dir, self.filename())
 
+    def abs_filepath(self):
+        return os.path.abspath(self.filepath())
+
     def breadcrumbs(self):
         """A list of parent dirs, plus the filename if it's not 'index.html'."""
         parent_dirs = os.path.dirname(self.canonical_filename()).split("/")
@@ -596,22 +599,33 @@ class Artifact(object):
         return self.document_key.replace("/","-").replace("|", "-")
 
     def url(self):
+        # TODO test for final
         return "/%s" % self.canonical_filename()
 
     def hyperlink(self, link_text = None):
+        # TODO test for final
         if not link_text:
             link_text = self.canonical_basename()
 
         return """<a href="%s">%s</a>""" % (self.url(), link_text)
 
-    def iframe(self, link_text = None):
+    def iframe(self, link_text = None, width = "600px", height = "300px"):
+        # TODO test for final
+        args = {
+                'url' : self.url(),
+                'hyperlink' : self.hyperlink(link_text),
+                'width' : width,
+                'height' : height
+        }
+
         return """
-<iframe src="%s">
-%s
+<iframe src="%(url)s" width="%(width)s" height="%(height)s" style="border: thin solid gray;">
+%(hyperlink)s
 </iframe>
-        """ % (self.url(), self.hyperlink(link_text))
+        """ % args
 
     def img(self):
+        # TODO test for final
         return """<img src="/%s" alt="Image generated by dexy %s" />""" % (self.canonical_filename(), self.key)
 
     def has_sections(self):
@@ -629,3 +643,4 @@ class Artifact(object):
     def relative_key_for_input(self, input_artifact):
         relpath = self.relative_path_to_input(input_artifact)
         return os.path.join(relpath, os.path.basename(input_artifact.key))
+
